<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Zunaj brskalnika je življenje!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Različica %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licenca pripada: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je prosta programska oprema, a njen razvoj zahteva dragocen čas.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Darujte prosim&lt;/a&gt; za podporo stalnemu razvoju %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Prevedite %1 v vaš jezik z uporabo programa %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikone je izrisal %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Izdano na podlagi licence &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Vnesite svoje licenčne podatke</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-pošta</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Koda:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Kupite prosim licenco %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Različica demo je potekla.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Polna verzija vam omogoča ogled posnetkov brez prekinitev.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Brez licence bo uporabnost aplikacije potekla čez %1 dni.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Z nakupom polne različice, boste podprli veliko truda, ki sem ga vložil v %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Uporabi demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Vpis licence</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Kupite licenco</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Prenesi</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Za %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Vsi videoposnetki</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Neogledani posnetki</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Naziv</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Nazadnje posodobljeno</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Nazadnje dodano</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Nazadnje gledano</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Največkrat gledano</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Razvrsti glede na</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Označi vse za pregledane</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Pokaži posodobitve</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Nimate naročnin. Uporabite zvezdo da se naročite na kanale.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Vsi videoposnetki</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Neogledani posnetki</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Označite kot ogledano</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Odjavite se</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Za zdaj ni nobenih novih posnetkov, na katere ste prijavljeni</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Ravnokar</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 predvajanj</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bajtov</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>byte/s</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>kB/s</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minut</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 ostaja</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 preneseno v %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Prenos končan</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Sprememba mesta ...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Izberite mesto prenosa</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Spremenili ste mesto prenosa.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Trenutni prenosi bodo še vedno šli v prejšnje mesto.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Prenos v: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Prenosi</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Nekdo je ponaredil namestitveno datoteko, najverjetneje virus</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 ni bilo mogoče zagnati. Poskusite še enkrat.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Ponovno namesti</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pavza</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Predvajaj/Pavza</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ustavi</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Ustavi predvajanje po trenutnem posnetku</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Naslednji posnetek</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Prejšnji posnetek</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Povečaj glasnost</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Zmanjšaj glasnost</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Nemo</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Išči naprej</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Išči nazaj</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Išči</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Išči posnetke in kanale po ključnih besedah</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Brskaj</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Brskaj posnetke po kategoriji</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Naročnine</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Naročanje kanalov</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Udobno se namestite</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>Po&amp;manjšaj</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>U&amp;stavi</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Ustavi predvajanje in se vrne v iskalni pogled</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>P&amp;redhodna</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Predhodna sled</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Pres&amp;koči</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Skoči na naslednji video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Predvajaj</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Nadaljuj s predvajanjem</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Celozaslonski način</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Gre v celozaslonski način</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Strnjen način</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Skrije predvajalni seznam in orodno vrstico</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Odpri stran &amp;Youtube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gre na stran posnetka na YouTube in ustavi predvajanje</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopiraj povezavo Youtube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopira povezavo YouTube trenutnega posnetka v odložišče</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopiraj &amp;URL toka video</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopira URL trenutnega video pretoka v odložišče</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>&amp;Poišči ostale dele posnetka</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Poišče ostale dele posnetka, predvidoma v pravem zaporedju</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Odst&amp;rani</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Odstrani izbrani video iz predvajalnega seznama</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Premakni &amp;gor</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Izbrani video premakne mesto više v predvajalnem seznamu</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Premakni &amp;dol</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Izbrani video premakne mesto niže v predvajalnem seznamu</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>Počisti nedavna iskanja</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Izbriše zgodovino iskanje. Tega dejanja ni mogoče razveljaviti.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Nasvidenje</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Spletno mesto</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na spletu</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Pošlji &amp;donacijo</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Podprite prosim nadaljni razvoj programa %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informacije o %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Išči</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Nemo</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Ročno začni predvajanje</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Prični z ročnim predvajanjem posnetkov</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>Pre&amp;nosi</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Pokaže podrobnosti o prenosih posnetkov</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>Pre&amp;nesi</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Prenese trenutni posnetek</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Vzemi &amp; Naredi Sliko</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Prijavi se na kanal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Deli trenutni posnetek preko %1 </translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;E-pošta</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-pošte</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>Lebdeče na vrhu</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>U&amp;stavi za tem posnetkom</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>P&amp;rijavi napako ...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Izboljšaj iskanje ...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Več ...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Povezani posnetki</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Glej posnetke, povezane s sedanjim</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Odpri v &amp;Brskalniku...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Omejeni način</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Skriti videoposnetki lahko vsebujejo neprimerno vsebino.</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Vam je všeč %1? Oceni!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Kupi %1 ...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplikacija</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Predvajanje</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Predvajalni seznam</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Deli</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Pogled</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>P&amp;omoč</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pritisnite %1, da povišate glasnost in %2, da jo nižate</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Izberi mesto za vsebino</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Odpiranje %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Ali res želite zapustiti %1 medtem, ko je aktiven prenos?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>V primeru, da zdaj zaprete %1 bo ta prenos prekinjen.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Zapri in prekliči prenos</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Počakaj, da konča prenos.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Napaka: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pavza</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Premor v predvajanju</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Nalaganje</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Zapusti celozaslonski način</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Preostali čas: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Glasnost %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Glasnost je utišana</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Glasnost je povrnjena</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Najvišja ločljivost posnetkov je nastavljena na %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Vaša zasebnost je zdaj varna</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Prenosi so končani</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>Na voljo je %1 različica %2.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Opozori me kasneje</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Posodobitev</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Zdaj lahko prilepite povezavo na YouTube v drugo aplikacijo</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Zdaj lahko prilepite URL video pretoka v drugo aplikacijo</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Povezava bo delovala le za omejen čas.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Prenašanje %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>od</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>del</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>nadaljevanje</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Poslano iz %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Odjavite se od %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Naroči se na %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Odjavljeni od %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Prijavljeni ste na %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Nova različica %1 je na voljo!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 je sedaj na voljo. Vi imate %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Bi jo radi prenesli sedaj?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Preskočite to verzijo</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Opomni me kasneje</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Namesti posodobitev</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Prilepi</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 od %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>V pripravi</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Neuspešno</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Dokončano</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Ustavljeno</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Ustavi prenos</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Pokaži v %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Odpri nadrejeno mapo</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Ponovno prenesi</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Pokaži %1 več</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nobenega videa</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nobenega videa več</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Razvrsti glede na</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Ustreznost</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Število ogledov</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Oceno</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Kadarkoli</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Danes</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dni</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dni</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trajanje</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Kratko</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Srednje</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Dolgo</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Manj kot 4 minute</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Med 4. in 20. minutami</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Daljše kot 20 minut</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvaliteta</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Visoka ločljivost</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p in višje</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Narejeno</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Išči</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Pozdravljeni v &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>in začnite gledati posnetke.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>ključno besedo</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Vnesite</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Nedavne ključne besede</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Nedavni kanali</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Pridobi celotno različico</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>Na&amp;zaj</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Naprej na %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Nazaj na %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Izboljšaj iskanje</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Ali ste mogoče mislili: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Sprememba mesta ...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Posnetek slike shranjen v %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Lokacija slik spremenjena</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Najbolj popularno</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Prenos posodobitve ...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Prenašanje %1 ...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Alžirija</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Avstralija</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgija</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazilija</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Čile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbija</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Češka republika</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egipt</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francija</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Nemčija</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Gana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grčija</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Madžarska</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Indija</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonezija</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irska</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Izrael</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italija</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japonska</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordanija</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenija</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malezija</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mehika</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maroko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Nizozemska</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nova Zelandija</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigerija</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipini</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Poljska</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusija</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Savdska Arabija</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Južna Afrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Južna Koreja</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Španija</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Švedska</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Tajvan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunizija</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turčija</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Združeni arabski emirati</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Združeno kraljestvo</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Svetovno</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Za %1 ni mogoče pridobiti video pretoka</translation>
    </message>
</context>
</TS>